@@ -3,9 +3,9 @@
  *
  * Testing program for fs/sakura_bind.c
  *
- * Copyright (C) 2005-2006  NTT DATA CORPORATION
+ * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.4   2007/04/01
+ * Version: 1.5.0   2007/09/20
  *
  */
 #include "include.h"
@@ -29,7 +29,7 @@ static void IPv4_TCP_Bind(void) {
 			if (bind(fd, (struct sockaddr *) &addr, sizeof(addr))) break;
 			size = sizeof(addr);
 			if (getsockname(fd, (struct sockaddr *) &addr, &size)) {
-				printf("getsockname() failed.\n"); fflush(stdout); exit(1);
+				printf("getsockname() failed.\n"); fflush(stdout); _exit(1);
 			} else {
 				const int port = ntohs(addr.sin_port);
 				if (!port || (port >= min_port && port <= max_port)) {
@@ -338,12 +338,12 @@ int main(int argc, char *argv[]) {
 	pid_t ipv4_pid = 0;
 	pid_t ipv6_pid = 0;
 	Init();
-	if ((system_fd = open("/proc/ccs/policy/system_policy", O_RDWR)) == EOF) {
-		fprintf(stderr, "Can't open /proc/ccs/policy/system_policy .\n");
+	if ((system_fd = open(proc_policy_system_policy, O_RDWR)) == EOF) {
+		fprintf(stderr, "Can't open %s .\n", proc_policy_system_policy);
 		return 1;
 	}
 	if (write(system_fd, "", 0) != 0) {
-		fprintf(stderr, "You need to register this program to /proc/ccs/policy/manager to run this program.\n");
+		fprintf(stderr, "You need to register this program to %s to run this program.\n", proc_policy_manager);
 		return 1;
 	}
 	{
